summaryrefslogtreecommitdiffstats
path: root/src/tellico_kernel.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/tellico_kernel.h')
-rw-r--r--src/tellico_kernel.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/tellico_kernel.h b/src/tellico_kernel.h
index bafa022..3ed211b 100644
--- a/src/tellico_kernel.h
+++ b/src/tellico_kernel.h
@@ -45,10 +45,10 @@ public:
/**
* Initializes the singleton. Should just be called once, from Tellico::MainWindow
*/
- static void init(MainWindow* tqparent) { if(!s_self) s_self = new Kernel(tqparent); }
+ static void init(MainWindow* parent) { if(!s_self) s_self = new Kernel(parent); }
/**
* Returns a pointer to the tqparent widget. This is mainly used for error dialogs and the like.
*
* @return The widget pointer
*/
@@ -130,7 +130,7 @@ private:
static Kernel* s_self;
// all constructors are private
- Kernel(MainWindow* tqparent);
+ Kernel(MainWindow* parent);
Kernel(const Kernel&);
Kernel& operator=(const Kernel&);
@@ -45,10 +45,10 @@ public:
/**
- * Returns a pointer to the tqparent widget. This is mainly used for error dialogs and the like.
+ * Returns a pointer to the parent widget. This is mainly used for error dialogs and the like.
*
* @return The widget pointer